==> quesadilla_core-0.1.0-py3-none-any.whl: quesadilla/connectors/protocol.py <==
# `quesadilla` - an elegant background task queue for the more civilized age
# Copyright (C) 2024 Artur Ciesielski <artur.ciesielski@gmail.com>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


from typing import Any, Protocol

import ulid

from quesadilla.core.task_serialization import SerializedTask


class Connector(Protocol):
    def queue(self, serialized: SerializedTask[Any]) -> None: ...  # pragma: nocover

    async def aqueue(
        self, serialized: SerializedTask[Any]
    ) -> None: ...  # pragma: nocover

    def find(
        self, namespace: str | None, task_queue: str, task_id: ulid.ULID
    ) -> SerializedTask[Any] | None: ...  # pragma: nocover

    async def afind(
        self, namespace: str | None, task_queue: str, task_id: ulid.ULID
    ) -> SerializedTask[Any] | None: ...  # pragma: nocover

    def pull(
        self, namespace: str | None, task_queue: str
    ) -> SerializedTask[Any] | None: ...  # pragma: nocover

    def update(
        self,
        namespace: str | None,
        task_queue: str,
        serialized: SerializedTask[Any],
    ) -> None: ...  # pragma: nocover

==> quesadilla_core-0.3.0-py3-none-any.whl: quesadilla/connectors/protocol.py <==
# `quesadilla` - an elegant background task queue for the more civilized age
# Copyright (C) 2024 Artur Ciesielski <artur.ciesielski@gmail.com>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


from typing import Any, Protocol

import ulid

from quesadilla.core.task_serialization import SerializedTask


class Connector(Protocol):
    def queue(self, serialized: SerializedTask[Any]) -> None: ...  # pragma: nocover

    async def aqueue(
        self, serialized: SerializedTask[Any]
    ) -> None: ...  # pragma: nocover

    def find(
        self, namespace: str, task_queue: str, task_id: ulid.ULID
    ) -> SerializedTask[Any] | None: ...  # pragma: nocover

    async def afind(
        self, namespace: str, task_queue: str, task_id: ulid.ULID
    ) -> SerializedTask[Any] | None: ...  # pragma: nocover

    def pull(
        self, namespace: str, task_queue: str
    ) -> SerializedTask[Any] | None: ...  # pragma: nocover

    def update(
        self,
        namespace: str,
        task_queue: str,
        serialized: SerializedTask[Any],
    ) -> None: ...  # pragma: nocover
